pub fn placement_remote_render_capability() -> CapabilityNameExpand description
Returns the capability required to render a fragment remotely.
pub fn placement_remote_render_capability() -> CapabilityNameReturns the capability required to render a fragment remotely.