pub struct ContentPeer {
pub node: Symbol,
pub serve: EvalFabricRef,
}Expand description
A peer that may hold content in its local cassette.
Fields
node: SymbolStable node id for diagnostics and later holder-index announcements.
serve: EvalFabricRefServe-only fabric for the peer’s held content.
Implementations
Sourceimpl ContentPeer
impl ContentPeer
Sourcepub fn new(node: Symbol, serve: EvalFabricRef) -> Self
pub fn new(node: Symbol, serve: EvalFabricRef) -> Self
Builds a peer handle from node and its serve fabric.